==> jboss-eap-7.4.3-src.zip: jboss-eap-7.4-src/testsuite/integration/basic/src/test/java/org/wildfly/test/integration/weld/asyncobserver/TestObserver.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2021, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.test.integration.weld.asyncobserver;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.event.ObservesAsync;
import javax.naming.InitialContext;
import javax.naming.NamingException;

@ApplicationScoped
public class TestObserver {

   public void recieve(@ObservesAsync TestEvent event) {
      try {
         InitialContext initialContext = new InitialContext();
         initialContext.lookup("java:comp/TransactionSynchronizationRegistry");
      } catch (NamingException e) {
         throw new RuntimeException(e);
      }
   }

   public static class TestEvent {

   }
}

==> jboss-eap-8.0.6-src.zip: jboss-eap-8.0-src/testsuite/integration/basic/src/test/java/org/wildfly/test/integration/weld/asyncobserver/TestObserver.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2021, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.test.integration.weld.asyncobserver;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.event.ObservesAsync;
import javax.naming.InitialContext;
import javax.naming.NamingException;

@ApplicationScoped
public class TestObserver {

   public void recieve(@ObservesAsync TestEvent event) {
      try {
         InitialContext initialContext = new InitialContext();
         initialContext.lookup("java:comp/TransactionSynchronizationRegistry");
      } catch (NamingException e) {
         throw new RuntimeException(e);
      }
   }

   public static class TestEvent {

   }
}
